import os
import ctypes

from . import CoreClass  # import python .so

core_path = os.path.dirname(__file__)

core_files = os.listdir(core_path)

so_files = dict()
for file in core_files:
    if file.endswith('.so'):
        prefix = file.split('.')[0]
        so_files[prefix] = file



# read C so
CoreFunction = ctypes.cdll.LoadLibrary(os.path.join(
    core_path
    , so_files['CoreFunction']
))



import os
import ctypes

core_path = os.path.dirname(__file__)


so_files = {file.split('.')[0]: os.path.join(core_path, file)
            for file in os.listdir(core_path)
            if file.endswith('.so')}

# read .so
CoreFunction = ctypes.cdll.LoadLibrary(so_files['CoreFunction'])



import my_build
from .. import module_path
from os.path import join
import os


def hello2():
    print("hello2")


def my_file():
    with open(os.path.join(module_path, 'data/a.txt')) as f:
        print(f.readlines())



from setuptools import setup
from setuptools import find_packages

# from distutils.core import setup
from distutils.extension import Extension
from Cython.Build import cythonize

print("installing my_build, it is an example for python extension!")

# 完全开源
setup(
    name='my_build',
    version='0.0.4',  # 版本号，每次上传的版本号应当不一样，可以用类似 sko.__version__ 去自动指定
    python_requires='>=3.5',
    packages=['my_build', 'my_build.sub', 'my_build.core', 'my_build.core_private'],
    ext_modules=[
        # c文件会编译为 .so 文件
        Extension(
            # 1)必须指定my_build，否则 so 文件直接生成到包的根目录下。
            # 2）my_add 是生成的so文件名，会自动添加后缀使其符合规范
            "my_build.core.CoreFunction",
            # 被编译的 c 文件
            ['my_build/core/CoreFunction.c'])
    ],

    # ext_modules=cythonize('my_build/hello.py')

    package_data={'my_build': ['data/*.txt', 'core_private/*.so']},
    # data_files=[('my_build', ['my_build/data/*.txt'])]

)

#
# # 核心保密：
# setup(
#     name='my_build',
#     version='0.0.2',  # 版本号，每次上传的版本号应当不一样，可以用类似 sko.__version__ 去自动指定
#     python_requires='>=3.5',
#     packages=['my_build', 'my_build.sub', 'my_build.core'],  # 这里不加入 my_build.core
#     # ext_modules=[
#     #     # c文件会编译为 .so 文件
#     #     Extension(
#     #         # 1)必须指定my_build，否则 so 文件直接生成到包的根目录下。
#     #         # 2）my_add 是生成的so文件名，会自动添加后缀使其符合规范
#     #         "my_build.my_add",
#     #         # 被编译的 c 文件
#     #         ['my_build/my_add.c', 'my_build/my_add2.c'])
#     # ],
#
#     # ext_modules=cythonize('my_build/hello.py')
#
#     package_data={'my_build': ['data/*.txt', 'core/__init__.py']},
#     ext_modules=cythonize(["my_build/core/CoreClass.py", 'my_build/core/CoreFunction.c'])
#     # data_files=[('my_build', ['my_build/data/*.txt'])]
#
# )
